@@ -9,6 +9,9 @@ class OmekaSGateway(object):
         self.key_identity = key_identity
         self.key_credential = key_credential
 
+    def set_site_id(self, site_id):
+        self.site_id = site_id
+
     def get_request_info(self, endpoint):
         stock_parameters = {
             'site_id': self.site_id,
@@ -38,11 +41,21 @@ class OmekaSGateway(object):
         r = requests.get(uri, params=params)
         return r.json()
 
-    def list_items(self, site_id):
+    def list_items(self):
         uri, params = self.get_request_info('items')
         r = requests.get(uri, params)
         return r.json()
 
+    def list_vocabularies(self):
+        uri, params = self.get_request_info('vocabularies')
+        r = requests.get(uri, params)
+        return r.json()
+
+    def list_sites(self):
+        uri, params = self.get_request_info('sites')
+        r = requests.get(uri, params)
+        return r.json()
+    
     def create_item_with_media(self, item_payload, path, mime_type):
         uri, params = self.get_request_info('items')
         r = requests.post(uri, params=params, data={'data': json.dumps(item_payload)}, files=[
